.. _dhlab.classes:

Classes
~~~~~~~~

.. currentmodule:: dhlab


.. autosummary::
   :recursive:
   :template: autosummary/toplevel_class.rst
   :toctree: generated

   Corpus
   Chunks
   Collocations
   Concordance
   Counts
   GeoData
   GeoNames
   NER
   POS
   Models
   WildcardWordSearch
   Ngram
   NgramBook
   NgramNews
   WordParadigm
   WordLemma
   WordForm
